@@ -64,6 +64,12 @@ pub fn bind(t: Bson, mut q: Query<Postgres, PgArguments>) -> crate::Result<Query
         Bson::Int64(n) => {
             q = q.bind(n);
         }
+        Bson::UInt32(n) => {
+            q = q.bind(n);
+        }
+        Bson::UInt64(n) => {
+            q = q.bind(n as i64);
+        }
         Bson::Double(n) => {
             q = q.bind(n);
         }
